@@ -2,27 +2,79 @@ import logging
 from datetime import datetime
 from typing import Iterable
 
-from fastapi import APIRouter, Depends, Request
+from fastapi import APIRouter, Depends, Request, BackgroundTasks
 from fastapi.responses import RedirectResponse
+from sendmail_container import FormDataRequest
 from starlette.datastructures import FormData
 
+from statina.API.external.api.api_v1.templates.email.account_activated import (
+    ACTIVATION_MESSAGE_TEMPLATE,
+)
+from statina.API.external.api.api_v1.templates.email.admin_mail import ADMIN_MESSAGE_TEMPLATE
 from statina.adapter import StatinaAdapter
 from statina.API.external.api.deps import get_current_user
 from statina.API.external.constants import CHROM_ABNORM
-from statina.config import get_nipt_adapter
+from statina.config import get_nipt_adapter, email_settings
 from statina.crud import update
 from statina.crud.delete import delete_batches
 from statina.crud.find import find
 from statina.models.database import DataBaseSample, User, Batch
+from statina.tools.email import send_email
 
 router = APIRouter()
 
 LOG = logging.getLogger(__name__)
 
 
+@router.get("/validate_user")
+async def validate_user(
+    username: str,
+    verification_hex: str,
+    background_tasks: BackgroundTasks,
+    adapter: StatinaAdapter = Depends(get_nipt_adapter),
+):
+    update_user: User = find.user(user_name=username, adapter=adapter)
+    response = RedirectResponse("/batches")
+    if not update_user:
+        response.set_cookie(key="info_type", value="danger")
+        response.set_cookie(
+            key="user_info",
+            value="No such user in the database",
+        )
+    elif update_user.verification_hex == verification_hex and update_user.role == "unconfirmed":
+        try:
+            update_user.role = "inactive"
+            update.update_user(adapter=adapter, user=update_user)
+            email_form = FormDataRequest(
+                sender_prefix=email_settings.sender_prefix,
+                email_server_alias=email_settings.email_server_alias,
+                request_uri=email_settings.mail_uri,
+                recipients=email_settings.admin_email,
+                mail_title="New user request",
+                mail_body=ADMIN_MESSAGE_TEMPLATE.format(
+                    username=update_user.username,
+                    user_email=update_user.email,
+                    website_uri=email_settings.website_uri,
+                ),
+            )
+            background_tasks.add_task(send_email, email_form)
+            response.set_cookie(
+                key="user_info",
+                value="Email confirmed! Your account will be activated after manual review",
+            )
+        except Exception as e:
+            response.set_cookie(key="info_type", value="danger")
+            response.set_cookie(
+                key="user_info",
+                value=f"Backend error ({e.__class__.__name__})! Your account will be activated after manual review",
+            )
+    return response
+
+
 @router.post("/update_user")
 async def update_user(
     request: Request,
+    background_tasks: BackgroundTasks,
     adapter: StatinaAdapter = Depends(get_nipt_adapter),
     user: User = Depends(get_current_user),
 ):
@@ -30,8 +82,22 @@ async def update_user(
         return RedirectResponse(request.headers.get("referer"))
     form = await request.form()
     update_user: User = find.user(email=form["user_email"], adapter=adapter)
-    update_user.role = form["role"]
+    old_role = update_user.role
+    new_role = form["role"]
+    update_user.role = new_role
     update.update_user(adapter=adapter, user=update_user)
+    if old_role in ["inactive", "unconfirmed"] and new_role not in ["inactive", "unconfirmed"]:
+        email_form = FormDataRequest(
+            sender_prefix=email_settings.sender_prefix,
+            email_server_alias=email_settings.email_server_alias,
+            request_uri=email_settings.mail_uri,
+            recipients=update_user.email,
+            mail_title="Your account has been activated",
+            mail_body=ACTIVATION_MESSAGE_TEMPLATE.format(
+                website_uri=email_settings.website_uri, username=update_user.username
+            ),
+        )
+        background_tasks.add_task(send_email, email_form)
     return RedirectResponse(request.headers.get("referer"))
 
 
