@@ -1,5 +1,6 @@
 from datetime import datetime
 from typing import Literal
+import secrets
 
 from pydantic import BaseModel, EmailStr
 
@@ -8,5 +9,12 @@ class User(BaseModel):
     username: str
     email: EmailStr
     added: datetime
-    role: Literal["R", "RW", "inactive", "admin"]
+    role: Literal[
+        "unconfirmed",
+        "inactive",
+        "R",
+        "RW",
+        "admin",
+    ]
     hashed_password: str
+    verification_hex: str = secrets.token_urlsafe(64)
